/********************************************************************
 * thinkfan.h: Top-level definitions.
 *
 * this file is part of thinkfan. See thinkfan.c for further information.
 *
 * thinkfan is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * thinkfan is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with thinkfan.  If not, see <http://www.gnu.org/licenses/>.
 * ******************************************************************/

#ifndef THINKFAN_H

#define THINKFAN_H
#define _GNU_SOURCE

int complex_lvl_up();
int complex_lvl_down();
int simple_lvl_up();
int simple_lvl_down();


#endif
